@@ -24,10 +24,12 @@ with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 /* This file contain java scripts for Action frame */
 
-const NUM_LIST_FRAME = 2;
-
 $(document).ready(function(){
     $('#action tbody.item td.select :button').bind('click', on_click_action);
+
+    // Additional params
+    $('#download_rate')             .bind('change', on_change_download_rate);
+    $('#upload_rate')               .bind('change', on_change_upload_rate);
 });
 
 function on_click_action()
@@ -40,6 +42,21 @@ function on_click_action()
     $.cookie('action', $(this).attr('class'), { expires: 730 });
 
     // Update List frame with new params
-    var objDocList = window.parent.frames[ NUM_LIST_FRAME ].document;
-    objDocList.location = 'index.cgi?show=list&action=' + $(this).attr('class');
+//    alert( $(window.parent.frames.frm_list).attr('id') );
+    window.parent.frames['frm_list'].location =
+        'index.cgi?show=list&action=' + $(this).attr('class');
+}
+
+function on_change_download_rate()
+{
+    // Update window with new locale
+    window.document.location =
+        'index.cgi?show=action&download_rate=' + $(this).val();
+}
+
+function on_change_upload_rate()
+{
+    // Update window with new locale
+    window.document.location =
+        'index.cgi?show=action&upload_rate=' + $(this).val();
 }
\ No newline at end of file
